@@ -1,3 +1,4 @@
+from sqlalchemy import Column, Enum
 from sqlmodel import Field
 
 from sql_models.SQLCamelModel import SQLCamelModel
@@ -5,6 +6,9 @@ from sql_models.shared.role.Role import Role
 
 
 class RoleVisibility(SQLCamelModel):
-    visibility: Role | None = Field(default=False)
+    visibility: Role | None = Field(
+        default=None,
+        sa_column=Column(Enum),
+    )
 
 
